<?php
/*
Plugin Name: GPT - WooCommerce Telegram Sale Notification
Description: Sends a Telegram message using the Telegram Bot API whenever a sale is made on your WooCommerce site. Configure the Telegram API key and allowed chat IDs in the admin settings.
Version: 1.0.0
Author: WPGPTCoder
Author URI: https://www.wpappdev.com/product/wp-gpt-coder/
Slug: woocommerce-telegram-sale-notification-11868819
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

class GPT_WooCommerce_Telegram_Sale_Notification_11868819 {
    private $options;

    public function __construct() {
        add_action('admin_menu', array($this, 'add_plugin_page'));
        add_action('admin_init', array($this, 'page_init'));
        add_action('woocommerce_order_status_completed', array($this, 'send_telegram_message_on_sale'), 10, 1);
    }

    public function add_plugin_page() {
        add_options_page(
            'WooCommerce Telegram Sale Notification', // page_title
            'Telegram Sale Notification', // menu_title
            'manage_options', // capability
            'telegram-sale-notification-11868819', // menu_slug
            array($this, 'create_admin_page') // function
        );
    }

    public function create_admin_page() {
        $this->options = get_option('telegram_sale_notification_11868819');
        ?>
        <div class="wrap">
            <h2>WooCommerce Telegram Sale Notification</h2>
            <form method="post" action="options.php">
            <?php
                settings_fields('telegram_option_group_11868819');
                do_settings_sections('telegram-sale-notification-11868819');
                submit_button();
            ?>
            </form>
        </div>
        <?php
    }

    public function page_init() {
        register_setting(
            'telegram_option_group_11868819', // option_group
            'telegram_sale_notification_11868819', // option_name
            array($this, 'sanitize') // sanitize_callback
        );

        add_settings_section(
            'setting_section_id_11868819', // id
            'Settings', // title
            array($this, 'print_section_info'), // callback
            'telegram-sale-notification-11868819' // page
        );

        add_settings_field(
            'platform', // id
            'Platform', // title
            array($this, 'platform_callback'), // callback
            'telegram-sale-notification-11868819', // page
            'setting_section_id_11868819' // section
        );

        add_settings_field(
            'api_key', 
            'API Key', 
            array($this, 'api_key_callback'), 
            'telegram-sale-notification-11868819', 
            'setting_section_id_11868819'
        );

        add_settings_field(
            'allowed_chat_ids', 
            'Allowed Chat IDs', 
            array($this, 'allowed_chat_ids_callback'), 
            'telegram-sale-notification-11868819', 
            'setting_section_id_11868819'
        );
    }

    public function sanitize($input) {
        $new_input = array();
        if (isset($input['api_key']))
            $new_input['api_key'] = sanitize_text_field($input['api_key']);

        if (isset($input['allowed_chat_ids']))
            $new_input['allowed_chat_ids'] = sanitize_text_field($input['allowed_chat_ids']);

        return $new_input;
    }

    public function print_section_info() {
        print 'Enter your Telegram settings below:';
    }

    public function platform_callback() {
        printf(
            '<input type="text" id="platform" name="telegram_sale_notification_11868819[platform]" value="Telegram" readonly />'
        );
    }

    public function api_key_callback() {
        printf(
            '<input type="text" id="api_key" name="telegram_sale_notification_11868819[api_key]" value="%s" />',
            isset($this->options['api_key']) ? esc_attr($this->options['api_key']) : ''
        );
    }

    public function allowed_chat_ids_callback() {
        printf(
            '<input type="text" id="allowed_chat_ids" name="telegram_sale_notification_11868819[allowed_chat_ids]" value="%s" />',
            isset($this->options['allowed_chat_ids']) ? esc_attr($this->options['allowed_chat_ids']) : ''
        );
    }

    public function send_telegram_message_on_sale($order_id) {
        $order = wc_get_order($order_id);
        $this->options = get_option('telegram_sale_notification_11868819');
        if (!$this->options || empty($this->options['api_key']) || empty($this->options['allowed_chat_ids'])) {
            return;
        }

        $chat_ids = explode(',', $this->options['allowed_chat_ids']);
        $api_key = $this->options['api_key'];
        $message_text = urlencode("A new sale has been made! Order #{$order_id}");

        foreach ($chat_ids as $chat_id) {
            $chat_id = trim($chat_id);
            $url = "https://api.telegram.org/bot{$api_key}/sendMessage?chat_id={$chat_id}&text={$message_text}";
            wp_remote_get($url);
        }
    }
}

new GPT_WooCommerce_Telegram_Sale_Notification_11868819();